==> websiteTest-0.1.0.tar.gz: websiteTest-0.1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=6.0', 'imutils==0.4.4', 'selenium==3.8.0', 'opencv-contrib-python==3.4.0.12',
                'opencv-python==3.4.0.12' ]

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest', ]

setup(
    author="Jose Reyes Garcia Delgado",
    author_email='reyes2000jose@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    description="A package to get visual differences between an expected template image and the actual website's appearance",
    entry_points={
        'console_scripts': [
            'websiteTest=websiteTest.cli:main',
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='websiteTest',
    name='websiteTest',
    packages=find_packages(include=['websiteTest']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/jotathebest/websiteTest',
    version='0.1.0',
    zip_safe=False,
)

==> websiteTest-0.1.1.tar.gz: websiteTest-0.1.1/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=6.0', 'imutils>=0.4.4', 'selenium>=3.8.0', 'opencv-contrib-python>=3.4.0.12',
                'opencv-python>=3.4.0.12']

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest', ]

setup(
    author="Jose Reyes Garcia Delgado",
    author_email='reyes2000jose@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    description="A package to get visual differences between an expected template image and the actual website’s appearance",
    entry_points={
        'console_scripts': [
            'websiteTest=websiteTest.cli:main',
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='websiteTest',
    name='websiteTest',
    packages=find_packages(include=['websiteTest']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/jotathebest/websiteTest',
    version='0.1.1',
    zip_safe=False,
)
